==> openshift-model-console-5.12.2-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleLinkBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConsoleLinkBuilder extends io.fabric8.openshift.api.model.console.v1.ConsoleLinkFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleLinkBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1.ConsoleLink,io.fabric8.openshift.api.model.console.v1.ConsoleLinkBuilder>{
  public ConsoleLinkBuilder() {
    this(false);
  }
  public ConsoleLinkBuilder(java.lang.Boolean validationEnabled) {
    this(new ConsoleLink(), validationEnabled);
  }
  public ConsoleLinkBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleLinkFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleLinkBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleLinkFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConsoleLink(), validationEnabled);
  }
  public ConsoleLinkBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleLinkFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleLink instance) {
    this(fluent, instance, false);
  }
  public ConsoleLinkBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleLinkFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleLink instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsoleLinkBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleLink instance) {
    this(instance,false);
  }
  public ConsoleLinkBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleLink instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1.ConsoleLinkFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1.ConsoleLink build() {
    ConsoleLink buildable = new ConsoleLink(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleLinkBuilder that = (ConsoleLinkBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-console-6.4.0-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleLinkBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConsoleLinkBuilder extends ConsoleLinkFluentImpl<ConsoleLinkBuilder> implements VisitableBuilder<ConsoleLink,ConsoleLinkBuilder>{
  public ConsoleLinkBuilder() {
    this(false);
  }
  public ConsoleLinkBuilder(Boolean validationEnabled) {
    this(new ConsoleLink(), validationEnabled);
  }
  public ConsoleLinkBuilder(ConsoleLinkFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleLinkBuilder(ConsoleLinkFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConsoleLink(), validationEnabled);
  }
  public ConsoleLinkBuilder(ConsoleLinkFluent<?> fluent,ConsoleLink instance) {
    this(fluent, instance, false);
  }
  public ConsoleLinkBuilder(ConsoleLinkFluent<?> fluent,ConsoleLink instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsoleLinkBuilder(ConsoleLink instance) {
    this(instance,false);
  }
  public ConsoleLinkBuilder(ConsoleLink instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ConsoleLinkFluent<?> fluent;
  Boolean validationEnabled;
  public ConsoleLink build() {
    ConsoleLink buildable = new ConsoleLink(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
